<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-urls?lang_cible=nl
// ** ne pas modifier le fichier **

return [

	// U
	'urls_description' => 'Beheer van de URL’s varianten (betekenisdragend of niet)  ',
	'urls_slogan' => 'Beheer van de URL varianten (betekenisdragend of niet)',
];
